/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 * Author: Siamak Haschemi
 * Contact: haschemi@informatik.hu-berlin.de
 */
package net.sourceforge.osgi.deployment.maven.container;

import java.io.File;

import net.sourceforge.osgi.deployment.maven.IDeploymentPluginContext;
import net.sourceforge.osgi.deployment.maven.IResource;


/**
 * 
 * <p>
 * From the Deployment Admin Specification:
 * </p>
 * <p>
 * A Deployment Package consists of installable <i>resources</i>. Resources are described in the <i>Name sections</i> of the Manifest. They are stored in the
 * JAR file under a path. This path is called the <i>resource id</i>. Subsets of these resources are the bundles. Bundles are treated differently from the
 * other resources by the Deployment Admin service.
 * </p>
 * 
 * @author Siamak Haschemi, haschemi@informatik.hu-berlin.de
 */
public class BundleResource implements IResource {
  private String m_groupId;
  private String m_artifactId;
  private String m_version;
  private boolean m_customizer;
  private File m_resolvedFile;
  private String m_targetPath;
  private IDeploymentPluginContext m_context;

  /**
   * Constructor which initializes the instance of the {@link BundleResource}.
   */
  public BundleResource() {
    m_groupId = null;
    m_artifactId = null;
    m_version = null;
    m_customizer = false;
    m_resolvedFile = null;
    m_targetPath = null;
    m_context = null;
  }

  /**
   * @param p_context
   *          the context to set
   */
  public final void setDeploymentContext(final IDeploymentPluginContext p_context) {
    m_context = p_context;
  }

  /**
   * @return the path and the name of the resource
   * @see net.sourceforge.osgi.deployment.maven.IResource#getResourceId()
   */
  public final String getResourceId() {
    if (m_resolvedFile == null) {
      m_resolvedFile = m_context.resolveResource(m_groupId, m_artifactId, m_version);
    }
    String resourceId = m_resolvedFile.getName();
    if (m_targetPath != null && m_targetPath.length() > 0) {
      resourceId = m_targetPath + "/" + resourceId;
    }
    return resourceId;
  }

  /**
   * @return the targetPath
   */
  public final String getTargetPath() {
    return m_targetPath;
  }

  /**
   * @param p_targetPath
   *          the targetPath to set
   */
  public final void setTargetPath(final String p_targetPath) {
    m_targetPath = p_targetPath;
  }

  /**
   * @return the customizer
   */
  public final boolean isCustomizer() {
    return m_customizer;
  }

  /**
   * @param p_customizer
   *          the customizer to set
   */
  public final void setCustomizer(final boolean p_customizer) {
    m_customizer = p_customizer;
  }

  /**
   * @return the groupId
   */
  public final String getGroupId() {
    return m_groupId;
  }

  /**
   * @param p_groupId
   *          the groupId to set
   */
  public final void setGroupId(final String p_groupId) {
    m_groupId = p_groupId;
  }

  /**
   * @return the artifactId
   */
  public final String getArtifactId() {
    return m_artifactId;
  }

  /**
   * @param p_artifactId
   *          the artifactId to set
   */
  public final void setArtifactId(final String p_artifactId) {
    m_artifactId = p_artifactId;
  }

  /**
   * @return the version
   */
  public final String getVersion() {
    return m_version;
  }

  /**
   * @param p_version
   *          the version to set
   */
  public final void setVersion(final String p_version) {
    m_version = p_version;
  }

  /**
   * @return the context
   */
  public final IDeploymentPluginContext getContext() {
    return m_context;
  }

  /**
   * @param p_context
   *          the context to set
   */
  public final void setContext(final IDeploymentPluginContext p_context) {
    m_context = p_context;
  }

  /**
   * @return the resolvedFile
   */
  public final File getResolvedFile() {
    if (m_resolvedFile == null) {
      m_resolvedFile = m_context.resolveResource(m_groupId, m_artifactId, m_version);
    }
    return m_resolvedFile;
  }

  /**
   * @param p_resolvedFile
   *          the resolvedFile to set
   */
  public final void setResolvedFile(final File p_resolvedFile) {
    m_resolvedFile = p_resolvedFile;
  }

  /**
   * @see java.lang.Object#toString()
   * @return a string representation of a {@link BundleResource}.
   */
  public final String toString() {
    final StringBuffer buffer = new StringBuffer(this.getClass().getName());
    buffer.append("[");
    buffer.append("groupId:");
    buffer.append(getGroupId());
    buffer.append(", ");
    buffer.append("artifactId:");
    buffer.append(getArtifactId());
    buffer.append(", ");
    buffer.append("version:");
    buffer.append(getVersion());
    buffer.append(", ");
    buffer.append("resolvedFile:");
    buffer.append(getResolvedFile());
    buffer.append("]");
    return buffer.toString();
  }
}
