/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 * Author: Siamak Haschemi
 * Contact: haschemi@informatik.hu-berlin.de
 */
package net.sourceforge.osgi.deployment.maven.container;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import net.sourceforge.osgi.deployment.maven.IResource;


/**
 * <p>
 * This class represents a Deployment-Package and stores some information about it.
 * </p>
 * <p>
 * The resources if a Deployment-Package are categorized in three groups:
 * <ul>
 * <li>Bundle-Resources</li>
 * <li>Localization-Resources</li>
 * <li>Processed-Resources</li>
 * </ul>
 * </p>
 * 
 * 
 * @author Siamak Haschemi, haschemi@informatik.hu-berlin.de
 */
public class DeploymentPackageInfo {
  private String m_bundleLocalization = null;
  private String m_symbolicName = null;
  private String m_copyright = null;
  private String m_description = null;
  private String m_version = null;
  private String m_contactAddress = null;
  private String m_docURL = null;
  private String m_vendor = null;
  private String m_fixPack = null;

  /**
   * The resources.
   * 
   * @parameter property="resources"
   */
  private List< IResource > m_resources = null;

  /**
   * A constructor which initializes an instance of a {@link DeploymentPackageInfo}.
   */
  public DeploymentPackageInfo() {
    m_resources = new ArrayList< IResource >();
  }

  /**
   * @return the description
   */
  public final String getDescription() {
    return m_description;
  }

  /**
   * @param p_description
   *          the description to set
   */
  public final void setDescription(final String p_description) {
    m_description = p_description;
  }

  /**
   * @return the version
   */
  public final String getVersion() {
    return m_version;
  }

  /**
   * @param p_version
   *          the version to set
   */
  public final void setVersion(final String p_version) {
    m_version = p_version;
  }

  /**
   * @return the copyright
   */
  public final String getCopyright() {
    return m_copyright;
  }

  /**
   * @param p_copyright
   *          the copyright to set
   */
  public final void setCopyright(final String p_copyright) {
    m_copyright = p_copyright;
  }

  /**
   * @return the contactAddress
   */
  public final String getContactAddress() {
    return m_contactAddress;
  }

  /**
   * @param p_contactAddress
   *          the contactAddress to set
   */
  public final void setContactAddress(final String p_contactAddress) {
    m_contactAddress = p_contactAddress;
  }

  /**
   * @return the docURL
   */
  public final String getDocURL() {
    return m_docURL;
  }

  /**
   * @param p_docURL
   *          the docURL to set
   */
  public final void setDocURL(final String p_docURL) {
    m_docURL = p_docURL;
  }

  /**
   * @return the vendor
   */
  public final String getVendor() {
    return m_vendor;
  }

  /**
   * @param p_vendor
   *          the vendor to set
   */
  public final void setVendor(final String p_vendor) {
    m_vendor = p_vendor;
  }

  /**
   * @return the fixPack
   */
  public final String getFixPack() {
    return m_fixPack;
  }

  /**
   * @param p_fixPack
   *          the fixPack to set
   */
  public final void setFixPack(final String p_fixPack) {
    m_fixPack = p_fixPack;
  }

  /**
   * @return the resources
   */
  public final List< IResource > getResources() {
    return m_resources;
  }

  /**
   * @param p_resources
   *          the resources to set
   */
  public final void setResources(final List< IResource > p_resources) {
    m_resources = p_resources;
  }

  /**
   * @return the symbolicName
   */
  public final String getSymbolicName() {
    return m_symbolicName;
  }

  /**
   * @param p_symbolicName
   *          the symbolicName to set
   */
  public final void setSymbolicName(final String p_symbolicName) {
    m_symbolicName = p_symbolicName;
  }

  /**
   * @return the bundleLocalization
   */
  public final String getBundleLocalization() {
    return m_bundleLocalization;
  }

  /**
   * @param p_bundleLocalization
   *          the bundleLocalization to set
   */
  public final void setBundleLocalization(final String p_bundleLocalization) {
    m_bundleLocalization = p_bundleLocalization;
  }

  /**
   * Resources can be Bundle-, Localization- or Processed-Resources. This method filters the whole resource list and returns only Bundle-Resources.
   * 
   * @return A filtered resource list where only Bundle-Resources are contained.
   */
  public final List< BundleResource > getBundleResources() {
    final List< BundleResource > list = new ArrayList< BundleResource >();
    for (final IResource resource : m_resources) {
      if (resource instanceof BundleResource) {
        list.add((BundleResource) resource);
      }
    }
    return list;
  }

  /**
   * Resources can be Bundle-, Localization- or Processed-Resources. This method filters the whole resource list and returns only Processed-Resources.
   * 
   * @return A filtered resource list where only Processed-Resources are contained.
   */
  public final List< ProcessedResource > getProcessedResources() {
    final List< ProcessedResource > list = new ArrayList< ProcessedResource >();
    for (final IResource resource : m_resources) {
      if (resource instanceof ProcessedResource) {
        list.add((ProcessedResource) resource);
      }
    }

    if (m_bundleLocalization != null && m_bundleLocalization.trim().length() >= 0) {
      for (final Iterator< ProcessedResource > i = list.iterator(); i.hasNext();) {
        final ProcessedResource processedResource = i.next();
        if (processedResource.getResourceId().startsWith(m_bundleLocalization)) {
          i.remove();
        }
      }
    }

    return list;
  }

  /**
   * Resources can be Bundle-, Localization- or Processed-Resources. This method filters the whole resource list and returns only Localization-Resources.
   * 
   * @return A filtered resource list where only Localization-Resources are contained.
   */
  public final List< ProcessedResource > getLocalizationResources() {
    final List< ProcessedResource > list = new ArrayList< ProcessedResource >();
    if (m_bundleLocalization == null || m_bundleLocalization.trim().length() == 0) {
      return list;
    }
    for (final IResource resource : m_resources) {
      if (resource instanceof ProcessedResource) {
        final ProcessedResource resource2 = (ProcessedResource) resource;
        if (resource2.getResourceId().startsWith(m_bundleLocalization)) {
          list.add(resource2);
        }
      }
    }
    return list;
  }

}
